@@ -1,5 +1,5 @@
 package Selenium::Firefox::Binary;
-$Selenium::Firefox::Binary::VERSION = '1.31';
+$Selenium::Firefox::Binary::VERSION = '1.32';
 use strict;
 use warnings;
 
@@ -8,10 +8,11 @@ use File::Which qw/which/;
 use Selenium::Firefox::Profile;
 
 require Exporter;
-our @ISA = qw/Exporter/;
+our @ISA       = qw/Exporter/;
 our @EXPORT_OK = qw/firefox_path setup_firefox_binary_env/;
 
 sub _firefox_windows_path {
+
     # TODO: make this slightly less dumb
     my @program_files = (
         $ENV{PROGRAMFILES} // 'C:\Program Files',
@@ -24,15 +25,17 @@ sub _firefox_windows_path {
     }
 
     # Fall back to a completely naive strategy
-    warn q/We couldn't find a viable firefox.EXE; you may want to specify it via the binary attribute./;
+    warn
+q/We couldn't find a viable firefox.EXE; you may want to specify it via the binary attribute./;
     return which('firefox');
 }
 
 sub _firefox_darwin_path {
-    my $default_firefox = '/Applications/Firefox.app/Contents/MacOS/firefox-bin';
+    my $default_firefox =
+      '/Applications/Firefox.app/Contents/MacOS/firefox-bin';
 
-    if (-e $default_firefox && -x $default_firefox) {
-        return $default_firefox
+    if ( -e $default_firefox && -x $default_firefox ) {
+        return $default_firefox;
     }
     else {
         return which('firefox-bin');
@@ -40,6 +43,7 @@ sub _firefox_darwin_path {
 }
 
 sub _firefox_unix_path {
+
     # TODO: maybe which('firefox3'), which('firefox2') ?
     return which('firefox') || '/usr/bin/firefox';
 }
@@ -47,17 +51,17 @@ sub _firefox_unix_path {
 
 sub firefox_path {
     my $path;
-    if ($^O eq 'MSWin32') {
-        $path =_firefox_windows_path();
+    if ( $^O eq 'MSWin32' ) {
+        $path = _firefox_windows_path();
     }
-    elsif ($^O eq 'darwin') {
+    elsif ( $^O eq 'darwin' ) {
         $path = _firefox_darwin_path();
     }
     else {
         $path = _firefox_unix_path;
     }
 
-    if (not -x $path) {
+    if ( not -x $path ) {
         die $path . ' is not an executable file.';
     }
 
@@ -68,21 +72,23 @@ sub firefox_path {
 # We want the profile to persist to the end of the session, not just
 # the end of this function.
 my $profile;
+
 sub setup_firefox_binary_env {
-    my ($port, $marionette_port, $caller_profile) = @_;
+    my ( $port, $marionette_port, $caller_profile ) = @_;
 
     $profile = $caller_profile || Selenium::Firefox::Profile->new;
-    $profile->add_webdriver($port, $marionette_port);
+    $profile->add_webdriver( $port, $marionette_port );
     $profile->add_marionette($marionette_port);
 
     # For non-geckodriver/marionette startup, we instruct Firefox to
     # use the profile by specifying the appropriate environment
     # variables for it to hook onto.
-    if (! $marionette_port) {
+    if ( !$marionette_port ) {
         $ENV{'XRE_PROFILE_PATH'} = $profile->_layout_on_disk;
-        $ENV{'MOZ_NO_REMOTE'} = '1'; # able to launch multiple instances
-        $ENV{'MOZ_CRASHREPORTER_DISABLE'} = '1'; # disable breakpad
-        $ENV{'NO_EM_RESTART'} = '1'; # prevent the binary from detaching from the console.log
+        $ENV{'MOZ_NO_REMOTE'} = '1';    # able to launch multiple instances
+        $ENV{'MOZ_CRASHREPORTER_DISABLE'} = '1';    # disable breakpad
+        $ENV{'NO_EM_RESTART'} =
+          '1';    # prevent the binary from detaching from the console.log
     }
     else {
         # In case the user created an old Firefox, which would've set
@@ -92,11 +98,11 @@ sub setup_firefox_binary_env {
         # load it in the new geckodriver Firefox, which would cause an
         # extension compatibility check
         my @env_vars = qw/
-                             XRE_PROFILE_PATH
-                             MOZ_NO_REMOTE
-                             MOZ_CRASHREPORTER_DISABLE
-                             NO_EM_RESTART
-                         /;
+          XRE_PROFILE_PATH
+          MOZ_NO_REMOTE
+          MOZ_CRASHREPORTER_DISABLE
+          NO_EM_RESTART
+          /;
 
         foreach (@env_vars) {
             delete $ENV{$_};
@@ -120,7 +126,7 @@ Selenium::Firefox::Binary - Subroutines for locating and properly initializing t
 
 =head1 VERSION
 
-version 1.31
+version 1.32
 
 =head1 SUBROUTINES
 
