@@ -1,5 +1,5 @@
 package Selenium::Remote::ErrorHandler;
-$Selenium::Remote::ErrorHandler::VERSION = '1.31';
+$Selenium::Remote::ErrorHandler::VERSION = '1.32';
 use strict;
 use warnings;
 
@@ -17,42 +17,42 @@ has STATUS_CODE => (
             7 => {
                 'code' => 'NO_SUCH_ELEMENT',
                 'msg' =>
-                  'An element could not be located on the page using the given search parameters.',
+'An element could not be located on the page using the given search parameters.',
             },
             8 => {
                 'code' => 'NO_SUCH_FRAME',
                 'msg' =>
-                  'A request to switch to a frame could not be satisfied because the frame could not be found.',
+'A request to switch to a frame could not be satisfied because the frame could not be found.',
             },
             9 => {
                 'code' => 'UNKNOWN_COMMAND',
                 'msg' =>
-                  'The requested resource could not be found, or a request was received using an HTTP method that is not supported by the mapped resource.',
+'The requested resource could not be found, or a request was received using an HTTP method that is not supported by the mapped resource.',
             },
             10 => {
                 'code' => 'STALE_ELEMENT_REFERENCE',
                 'msg' =>
-                  'An element command failed because the referenced element is no longer attached to the DOM.',
+'An element command failed because the referenced element is no longer attached to the DOM.',
             },
             11 => {
                 'code' => 'ELEMENT_NOT_VISIBLE',
                 'msg' =>
-                  'An element command could not be completed because the element is not visible on the page.',
+'An element command could not be completed because the element is not visible on the page.',
             },
             12 => {
                 'code' => 'INVALID_ELEMENT_STATE',
                 'msg' =>
-                  'An element command could not be completed because the element is in an invalid state (e.g. attempting to click a disabled element).',
+'An element command could not be completed because the element is in an invalid state (e.g. attempting to click a disabled element).',
             },
             13 => {
                 'code' => 'UNKNOWN_ERROR',
                 'msg' =>
-                  'An unknown server-side error occurred while processing the command.',
+'An unknown server-side error occurred while processing the command.',
             },
             15 => {
                 'code' => 'ELEMENT_IS_NOT_SELECTABLE',
                 'msg' =>
-                  'An attempt was made to select an element that cannot be selected.',
+'An attempt was made to select an element that cannot be selected.',
             },
             19 => {
                 'code' => 'XPATH_LOOKUP_ERROR',
@@ -67,12 +67,12 @@ has STATUS_CODE => (
             23 => {
                 'code' => 'NO_SUCH_WINDOW',
                 'msg' =>
-                  'A request to switch to a different window could not be satisfied because the window could not be found.',
+'A request to switch to a different window could not be satisfied because the window could not be found.',
             },
             24 => {
                 'code' => 'INVALID_COOKIE_DOMAIN',
                 'msg' =>
-                  'An illegal attempt was made to set a cookie under a different domain than the current page.',
+'An illegal attempt was made to set a cookie under a different domain than the current page.',
             },
             25 => {
                 'code' => 'UNABLE_TO_SET_COOKIE',
@@ -86,7 +86,7 @@ has STATUS_CODE => (
             27 => {
                 'code' => 'NO_ALERT_OPEN_ERROR',
                 'msg' =>
-                  'An attempt was made to operate on a modal dialog when one was not open.',
+'An attempt was made to operate on a modal dialog when one was not open.',
             },
             28 => {
                 'code' => 'SCRIPT_TIMEOUT',
@@ -96,7 +96,7 @@ has STATUS_CODE => (
             29 => {
                 'code' => 'INVALID_ELEMENT_COORDINATES',
                 'msg' =>
-                  'The coordinates provided to an interactions operation are invalid.',
+'The coordinates provided to an interactions operation are invalid.',
             },
             30 => {
                 'code' => 'IME_NOT_AVAILABLE',
@@ -116,7 +116,8 @@ has STATUS_CODE => (
 
 
 sub process_error {
-    my ($self, $resp) = @_;
+    my ( $self, $resp ) = @_;
+
     # TODO: Handle screen if it sent back with the response. Either we could
     # let the end user handle it or we can save it an image file at a temp
     # location & return the path.
@@ -126,10 +127,15 @@ sub process_error {
     $resp->{status} = 13 unless $resp->{status};
 
     my $ret;
+
     #XXX capitalization is inconsistent among geckodriver versions
-    $ret->{'stackTrace'} = $resp->{'value'}->{'stacktrace'} // $resp->{'value'}->{'stackTrace'};
-    $ret->{'error'}      = $is_stacktrace ? $resp->{value}->{error} : $self->STATUS_CODE->{$resp->{'status'}};
-    $ret->{'message'}    = $resp->{'value'}->{'message'};
+    $ret->{'stackTrace'} = $resp->{'value'}->{'stacktrace'}
+      // $resp->{'value'}->{'stackTrace'};
+    $ret->{'error'} =
+        $is_stacktrace
+      ? $resp->{value}->{error}
+      : $self->STATUS_CODE->{ $resp->{'status'} };
+    $ret->{'message'} = $resp->{'value'}->{'message'};
 
     return $ret;
 }
@@ -148,7 +154,7 @@ Selenium::Remote::ErrorHandler - Error handler for Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 1.31
+version 1.32
 
 =head1 SUBROUTINES
 
