@@ -1,5 +1,5 @@
 package Selenium::Remote::WebElement;
-$Selenium::Remote::WebElement::VERSION = '1.31';
+$Selenium::Remote::WebElement::VERSION = '1.32';
 # ABSTRACT: Representation of an HTML Element used by Selenium Remote Driver
 
 use strict;
@@ -10,18 +10,20 @@ use Carp qw(carp croak);
 
 
 has 'id' => (
-    is => 'ro',
+    is       => 'ro',
     required => 1,
-    coerce => sub {
+    coerce   => sub {
         my ($value) = @_;
-        if (ref($value) eq 'HASH') {
-            if (exists $value->{ELEMENT}) {
+        if ( ref($value) eq 'HASH' ) {
+            if ( exists $value->{ELEMENT} ) {
+
                 # The JSONWireProtocol web element object looks like
                 #
                 #     { "ELEMENT": $INTEGER_ID }
                 return $value->{ELEMENT};
             }
-            elsif (exists $value->{'element-6066-11e4-a52e-4f735466cecf'}) {
+            elsif ( exists $value->{'element-6066-11e4-a52e-4f735466cecf'} ) {
+
                 # but the WebDriver spec web element uses a magic
                 # string. See the spec for more information:
                 #
@@ -29,7 +31,8 @@ has 'id' => (
                 return $value->{'element-6066-11e4-a52e-4f735466cecf'};
             }
             else {
-                croak 'When passing in an object to the WebElement id attribute, it must have at least one of the ELEMENT or element-6066-11e4-a52e-4f735466cecf keys.';
+                croak
+'When passing in an object to the WebElement id attribute, it must have at least one of the ELEMENT or element-6066-11e4-a52e-4f735466cecf keys.';
             }
         }
         else {
@@ -39,9 +42,9 @@ has 'id' => (
 );
 
 has 'driver' => (
-    is => 'ro',
+    is       => 'ro',
     required => 1,
-    handles => [qw(_execute_command)],
+    handles  => [qw(_execute_command)],
 );
 
 
@@ -63,11 +66,22 @@ sub click {
 
 sub submit {
     my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
-        if ($self->get_tag_name() ne 'form') {
-            return $self->driver->execute_script("return arguments[0].form.submit();",{'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}} );
-        } else {
-            return $self->driver->execute_script("return arguments[0].submit();",{'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}} );
+    if (
+        $self->driver->{is_wd3}
+        && !(
+            grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge}
+        )
+      )
+    {
+        if ( $self->get_tag_name() ne 'form' ) {
+            return $self->driver->execute_script(
+                "return arguments[0].form.submit();",
+                { 'element-6066-11e4-a52e-4f735466cecf' => $self->{id} } );
+        }
+        else {
+            return $self->driver->execute_script(
+                "return arguments[0].submit();",
+                { 'element-6066-11e4-a52e-4f735466cecf' => $self->{id} } );
         }
     }
     my $res = { 'command' => 'submitElement', 'id' => $self->id };
@@ -85,10 +99,10 @@ sub send_keys {
     # corresponding value must be ('h', 'e', 'l', 'l', 'o' ). This
     # format conforms with the Spec AND works with the Selenium
     # standalone server.
-    my $strings = join('', map { $_."" } @strings);
+    my $strings = join( '', map { $_ . "" } @strings );
     my $params = {
-        'value' => [ split('', $strings) ],
-        text => $strings,
+        'value' => [ split( '', $strings ) ],
+        text    => $strings,
     };
     return $self->_execute_command( $res, $params );
 }
@@ -97,7 +111,10 @@ sub send_keys {
 sub is_selected {
     my ($self) = @_;
 
-    return $self->get_property('checked') if $self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge});
+    return $self->get_property('checked')
+      if $self->driver->{is_wd3}
+      && !( grep { $self->driver->browser_name eq $_ }
+        qw{chrome MicrosoftEdge} );
     my $res = { 'command' => 'isElementSelected', 'id' => $self->id };
     return $self->_execute_command($res);
 }
@@ -105,7 +122,7 @@ sub is_selected {
 
 sub set_selected {
     my ($self) = @_;
-    if ($self->driver->{is_wd3}) {
+    if ( $self->driver->{is_wd3} ) {
         return if $self->is_selected();
         return $self->click();
     }
@@ -116,9 +133,12 @@ sub set_selected {
 
 sub toggle {
     my ($self) = @_;
-    if ($self->driver->{is_wd3}) {
+    if ( $self->driver->{is_wd3} ) {
         return $self->click() unless $self->is_selected();
-        return $self->driver->execute_script(qq/ if (arguments[0].checked) { arguments[0].checked = 0 }; return arguments[0].checked; /, {'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}});
+        return $self->driver->execute_script(
+qq/ if (arguments[0].checked) { arguments[0].checked = 0 }; return arguments[0].checked; /,
+            { 'element-6066-11e4-a52e-4f735466cecf' => $self->{id} }
+        );
     }
     my $res = { 'command' => 'toggleElement', 'id' => $self->id };
     return $self->_execute_command($res);
@@ -127,7 +147,13 @@ sub toggle {
 
 sub is_enabled {
     my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
+    if (
+        $self->driver->{is_wd3}
+        && !(
+            grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge}
+        )
+      )
+    {
         return 1 if $self->get_tag_name() ne 'input';
         return $self->get_property('disabled') ? 0 : 1;
     }
@@ -138,7 +164,13 @@ sub is_enabled {
 
 sub get_element_location {
     my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
+    if (
+        $self->driver->{is_wd3}
+        && !(
+            grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge}
+        )
+      )
+    {
         my $data = $self->get_element_rect();
         delete $data->{height};
         delete $data->{width};
@@ -151,7 +183,13 @@ sub get_element_location {
 
 sub get_size {
     my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
+    if (
+        $self->driver->{is_wd3}
+        && !(
+            grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge}
+        )
+      )
+    {
         my $data = $self->get_element_rect();
         delete $data->{x};
         delete $data->{y};
@@ -162,7 +200,6 @@ sub get_size {
 }
 
 
-
 sub get_element_rect {
     my ($self) = @_;
     my $res = { 'command' => 'getElementRect', 'id' => $self->id };
@@ -172,15 +209,20 @@ sub get_element_rect {
 
 sub get_element_location_in_view {
     my ($self) = @_;
+
     #XXX chrome is dopey here
-    return $self->driver->execute_script(qq{
+    return $self->driver->execute_script(
+        qq{
         if (typeof(arguments[0]) !== 'undefined' && arguments[0].nodeType === Node.ELEMENT_NODE) {
             arguments[0].scrollIntoView();
             var pos = arguments[0].getBoundingClientRect();
             return {y:pos.top,x:pos.left};
         }
         return {};
-    }, {'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}} ) if $self->driver->{is_wd3} && grep { $self->driver->browser_name eq $_ } ('firefox','internet explorer');
+    }, { 'element-6066-11e4-a52e-4f735466cecf' => $self->{id} }
+      )
+      if $self->driver->{is_wd3} && grep { $self->driver->browser_name eq $_ }
+      ( 'firefox', 'internet explorer' );
     my $res = { 'command' => 'getElementLocationInView', 'id' => $self->id };
     return $self->_execute_command($res);
 }
@@ -209,7 +251,11 @@ sub get_attribute {
     #Handle global JSONWire emulation flag
     $no_i_really_mean_it = 1 unless $self->{driver}->{emulate_jsonwire};
 
-    return $self->get_property($attr_name) if $self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge}) && !$no_i_really_mean_it;
+    return $self->get_property($attr_name)
+      if $self->driver->{is_wd3}
+      && !( grep { $self->driver->browser_name eq $_ }
+        qw{chrome MicrosoftEdge} )
+      && !$no_i_really_mean_it;
 
     my $res = {
         'command' => 'getElementAttribute',
@@ -221,14 +267,17 @@ sub get_attribute {
 
 
 sub get_property {
-    my ($self,$prop) = @_;
-    return $self->get_attribute($prop) if $self->driver->{is_wd3} && (grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge});
-    my $res = { 'command' => 'getElementProperty', id => $self->id, name => $prop };
+    my ( $self, $prop ) = @_;
+    return $self->get_attribute($prop)
+      if $self->driver->{is_wd3}
+      && ( grep { $self->driver->browser_name eq $_ }
+        qw{chrome MicrosoftEdge} );
+    my $res =
+      { 'command' => 'getElementProperty', id => $self->id, name => $prop };
     return $self->_execute_command($res);
 }
 
 
-
 sub get_value {
     my ($self) = @_;
     return $self->get_attribute('value');
@@ -237,10 +286,18 @@ sub get_value {
 
 sub is_displayed {
     my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
-        return 0 if $self->get_tag_name() eq 'input' && $self->get_property('type') eq 'hidden'; #hidden type inputs
+    if (
+        $self->driver->{is_wd3}
+        && !(
+            grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge}
+        )
+      )
+    {
+        return 0
+          if $self->get_tag_name() eq 'input'
+          && $self->get_property('type') eq 'hidden';    #hidden type inputs
         return 0 unless $self->_is_in_viewport();
-        return int($self->get_css_attribute('display') ne 'none');
+        return int( $self->get_css_attribute('display') ne 'none' );
     }
     my $res = { 'command' => 'isElementDisplayed', 'id' => $self->id };
     return $self->_execute_command($res);
@@ -248,7 +305,8 @@ sub is_displayed {
 
 sub _is_in_viewport {
     my ($self) = @_;
-    return $self->driver->execute_script(qq{
+    return $self->driver->execute_script(
+        qq{
         var rect = arguments[0].getBoundingClientRect();
         return (
             rect.top >= 0 &&
@@ -256,21 +314,22 @@ sub _is_in_viewport {
             rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) &&
             rect.right <= (window.innerWidth || document.documentElement.clientWidth)
         );
-    },{'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}});
+    }, { 'element-6066-11e4-a52e-4f735466cecf' => $self->{id} }
+    );
 }
 
 
 sub is_hidden {
     my ($self) = @_;
-    return ! $self->is_displayed();
+    return !$self->is_displayed();
 }
 
 
 sub drag {
-    my ($self,$target) = @_;
+    my ( $self, $target ) = @_;
     require Selenium::ActionChains;
-    my $chain = Selenium::ActionChians->new( driver => $self->driver );
-    return $chain->drag_and_drop($self,$target)->perform();
+    my $chain = Selenium::ActionChains->new( driver => $self->driver );
+    return $chain->drag_and_drop( $self, $target )->perform();
 }
 
 
@@ -303,11 +362,11 @@ sub describe {
 
 
 sub screenshot {
-    my ($self, $scroll) = @_;
+    my ( $self, $scroll ) = @_;
     $scroll //= 1;
     my $res = { 'command' => 'elementScreenshot', id => $self->id };
-    my $input = {scroll => int($scroll) };
-    return $self->_execute_command($res, $input);
+    my $input = { scroll => int($scroll) };
+    return $self->_execute_command( $res, $input );
 }
 
 
@@ -322,8 +381,6 @@ sub capture_screenshot {
     return 1;
 }
 
-
-
 1;
 
 __END__
@@ -338,7 +395,7 @@ Selenium::Remote::WebElement - Representation of an HTML Element used by Seleniu
 
 =head1 VERSION
 
-version 1.31
+version 1.32
 
 =head1 DESCRIPTION
 
